@@ -14,20 +14,19 @@ use App::Cmd::Setup -command;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-----------------------------------------------------------------------------
 
 sub usage_desc {
-    my ( $class_or_self, @args ) = @_;
+    my ($class_or_self, @args) = @_;
 
-    my $class = ref $class_or_self || $class_or_self;
-    my $file = $class . '.pm';
-    $file =~ s{::}{/}xg;
-    my $path = $INC{$file} or return;
+    my $class  = ref $class_or_self || $class_or_self;
+    my $file   = $class . '.pm'; $file =~ s{::}{/}xg;
+    my $path   = $INC{$file} or return;
     my $handle = IO::String->new;
 
-    pod2usage( -output => $handle, -input => $path, -exitval => 'NOEXIT' );
+    pod2usage(-output => $handle, -input => $path, -exitval => 'NOEXIT');
 
     return ${ $handle->string_ref };
 }
@@ -42,10 +41,10 @@ sub pinto {
 #-----------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     $self->usage_error("Arguments are not allowed")
-        if @{$args} and not $self->args_attribute;
+      if @{ $args } and not $self->args_attribute;
 
     return 1;
 }
@@ -53,10 +52,10 @@ sub validate_args {
 #------------------------------------------------------------------------------
 
 sub execute {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    my %args = $self->process_args($opts, $args);
-    my $result = $self->pinto->run( $self->action_name, %{$opts}, %args );
+    my %args = $self->process_args($args);
+    my $result = $self->pinto->run($self->action_name, %{$opts}, %args);
 
     return $result->exit_status;
 }
@@ -64,15 +63,15 @@ sub execute {
 #-----------------------------------------------------------------------------
 
 sub process_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $args) = @_;
 
     my $attr_name = $self->args_attribute or return;
 
-    if ( !@{$args} && $self->args_from_stdin($opts) ) {
-        return ( $attr_name => [ _args_from_fh( \*STDIN ) ] );
+    if ( ! @{$args} && $self->args_from_stdin) {
+        return ($attr_name => [ _args_from_fh(\*STDIN) ]);
     }
 
-    return ( $attr_name => $args );
+    return ($attr_name => $args);
 }
 
 #-----------------------------------------------------------------------------
@@ -80,7 +79,7 @@ sub process_args {
 sub action_name {
     my ($self) = @_;
 
-    my $class  = ref $self;
+    my $class = ref $self;
     my $prefix = $self->command_namespace_prefix();
 
     $class =~ m/ ^ ${prefix}:: (.+) /mx
@@ -99,7 +98,7 @@ sub _args_from_fh {
     my ($fh) = @_;
 
     my @args;
-    while ( my $line = <$fh> ) {
+    while (my $line = <$fh>) {
         chomp $line;
         next if not length $line;
         next if $line =~ m/^ \s* [;#]/x;
@@ -129,8 +128,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -139,7 +136,53 @@ App::Pinto::Command - Base class for pinto commands
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
 
 =head1 AUTHOR
 
@@ -147,7 +190,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
