@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,21 +20,22 @@ sub command_names { return qw(copy cp) }
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
     return (
-        [ 'default'         => 'Make the new stack the default stack' ],
-        [ 'description|d=s' => 'Brief description of the stack' ],
+        [ 'default'         => 'Make the new stack the default stack'  ],
+        [ 'description|d=s' => 'Brief description of the stack'        ],
         [ 'lock'            => 'Lock the new stack to prevent changes' ],
     );
 
+
 }
 
 #------------------------------------------------------------------------------
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    $self->usage_error('Must specify STACK and TO_STACK')
+    $self->usage_error('Must specify FROM_STACK and TO_STACK')
         if @{$args} != 2;
 
     return 1;
@@ -43,10 +44,10 @@ sub validate_args {
 #------------------------------------------------------------------------------
 
 sub execute {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    my %stacks = ( stack => $args->[0], to_stack => $args->[1] );
-    my $result = $self->pinto->run( $self->action_name, %{$opts}, %stacks );
+    my %stacks = ( from_stack => $args->[0], to_stack => $args->[1] );
+    my $result = $self->pinto->run($self->action_name, %{$opts}, %stacks);
 
     return $result->exit_status;
 }
@@ -58,8 +59,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -68,11 +67,11 @@ App::Pinto::Command::copy - create a new stack by copying another
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT copy [OPTIONS] STACK TO_STACK
+  pinto --root=REPOSITORY_ROOT copy [OPTIONS] FROM_STACK TO_STACK
 
 =head1 DESCRIPTION
 
@@ -80,15 +79,15 @@ This command creates a new stack by copying an existing one.  All the
 pins and properties from the existing stack will also be copied to the
 new one.  The new stack must not already exist.
 
-Use the L<new|App::Pinto::Command::new> command to create a new empty
-stack, or the L<props|App::Pinto::Command::props> command to change
+Use the L<new|App::Pinto::Command::new> command to create a new empty 
+stack, or the L<props|App::Pinto::Command::props> command to change 
 a stack's properties after it has been created.
 
 =head1 COMMAND ARGUMENTS
 
 The two required arguments are the name of the source and target
-stacks.  Stack names must be alphanumeric plus hyphens, underscores,
-and periods, and are not case-sensitive.
+stacks.  Stack names must be alphanumeric plus hyphens and underscores,
+and are not case-sensitive.
 
 =head1 COMMAND OPTIONS
 
@@ -103,7 +102,7 @@ Also mark the new stack as the default stack.
 =item -d TEXT
 
 Use TEXT for the description of the stack.  If not specified, defaults
-to 'Copy of stack STACK'.
+to 'Copy of stack FROM_STACK'.
 
 =item --lock
 
@@ -114,13 +113,59 @@ L<unlock|App::Pinto::Command::unlock> commands at a later time.
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
