@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -20,9 +20,11 @@ sub command_names { return qw(delete remove del rm) }
 #-----------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
-    return ( [ 'force' => 'Delete even if packages are pinned' ], );
+    return (
+        [ 'force'  => 'Delete even if packages are pinned'  ],
+    );
 }
 
 #------------------------------------------------------------------------------
@@ -40,8 +42,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -50,11 +50,11 @@ App::Pinto::Command::delete - permanently remove an archive
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT delete [OPTIONS] TARGET ...
+  pinto --root=REPOSITORY_ROOT deiete [OPTIONS] TARGET ...
 
 =head1 DESCRIPTION
 
@@ -75,8 +75,8 @@ use the L<unregister|App::Pinto::Command::unregister> command.
 
 =head1 COMMAND ARGUMENTS
 
-Arguments are the targets that you want to delete.  Targets are
-specified as C<AUTHOR/FILENAME>.  For example:
+Arguments are the archives that you want to delete.  Archives are
+specified as C<AUTHOR/ARCHIVE-NAME>.  For example:
 
   SHAKESPEARE/King-Lear-1.2.tar.gz
 
@@ -96,13 +96,59 @@ particular package is important to someone.
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
