@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,15 +20,17 @@ sub command_names { return qw(kill) }
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
-    return ( [ 'force' => 'Kill even if stack is locked' ], );
+    return (
+        [ 'force'  => 'Kill even if stack is locked'  ],
+    );
 }
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     $self->usage_error('Must specify exactly one stack')
         if @{$args} != 1;
@@ -39,9 +41,10 @@ sub validate_args {
 #------------------------------------------------------------------------------
 
 sub execute {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    my $result = $self->pinto->run( $self->action_name, %{$opts}, stack => $args->[0] );
+    my $result = $self->pinto->run($self->action_name, %{$opts},
+                                                       stack => $args->[0]);
 
     return $result->exit_status;
 }
@@ -53,8 +56,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -63,7 +64,7 @@ App::Pinto::Command::kill - permanently delete a stack
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -93,13 +94,59 @@ as it usually means the stack is important to someone.
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
