@@ -11,23 +11,25 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
-    return ( [ 'stack|s=s' => 'Lock this stack' ], );
+    return (
+        [ 'stack|s=s' => 'Lock this stack' ],
+    );
 }
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     $self->usage_error('Multiple arguments are not allowed')
-        if @{$args} > 1;
+        if @{ $args } > 1;
 
     $opts->{stack} = $args->[0]
         if $args->[0];
@@ -43,8 +45,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -53,7 +53,7 @@ App::Pinto::Command::lock - mark a stack as read-only
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -96,13 +96,59 @@ repository.
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
