@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,21 +20,19 @@ sub command_names { return qw(log history) }
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
-    return ( 
-    	[ 'stack|s=s'    => 'Show history for this stack'  ],
-      [ 'with-diffs|d' => 'Show a diff for each revision'], 
-      [ 'diff-style=s' => 'Diff style (concise|detailed)' ],
+    return (
+        [ 'stack|s=s' => 'Show history for this stack' ],
     );
 }
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    $self->usage_error('Multiple arguments are not allowed') if @{$args} > 1;
+    $self->usage_error('Multiple arguments are not allowed') if @{ $args } > 1;
 
     $opts->{stack} = $args->[0] if $args->[0];
 
@@ -49,8 +47,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -59,7 +55,7 @@ App::Pinto::Command::log - show the revision logs of a stack
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -69,7 +65,9 @@ version 0.11_01
 
 !! THIS COMMAND IS EXPERIMENTAL !!
 
-This command shows the revision logs for the stack.
+This command shows the commit logs for the stack.  To see the precise
+changes in any particular commit, use the L<App::Pinto::Command::show>
+command.
 
 =head1 COMMAND ARGUMENTS
 
@@ -88,14 +86,6 @@ be shown.
 
 =over 4
 
-=item --with-diffs
-
-=item -d
-
-For each revision, also show the diff from the previous revision.
-If the C<PINTO_DETAILED_DIFF> environment varaible is set to a 
-true value, a detailed diff will be shown.
-
 =item --stack NAME
 
 =item -s NAME
@@ -107,13 +97,59 @@ repository.
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
