@@ -1,7 +1,7 @@
-# ABSTRACT: show the full manual for a command
-
 package App::Pinto::Command::manual;
 
+# ABSTRACT: show the full manual for a command
+
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ use base qw(App::Pinto::Command);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -20,9 +20,9 @@ sub command_names { return qw( manual man --man ) }
 #-----------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    $self->usage_error("Must specify a command") if @{$args} != 1;
+    $self->usage_error("Must specify a command") if @{ $args } != 1;
 
     return 1;
 }
@@ -31,25 +31,18 @@ sub validate_args {
 # This was stolen from App::Cmd::Command::help
 
 sub execute {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
-    my ( $cmd, undef, undef ) = $self->app->prepare_command(@$args);
+    my ($cmd, undef, undef) = $self->app->prepare_command(@$args);
 
     my $class = ref $cmd;
-
-    # An invalid command name was specified, so the fallback command class 
-    # was returned.  Rather than showing the (unhelpful) manual for 
-    # App::Cmd::Command::commands, we will just bail out and let App::Cmd
-    # show the usual 'unrecognized command' message.
-    return 1 if $class eq 'App::Cmd::Command::commands';
-
-    ( my $relative_path = $class ) =~ s< :: ></>xmsg;
+    (my $relative_path = $class) =~ s< :: ></>xmsg;
     $relative_path .= '.pm';
 
     my $absolute_path = $INC{$relative_path}
-        or die "No manual available for $class\n";
+        or die "No manual available for $class\n"; 
 
-    pod2usage( -verbose => 2, -input => $absolute_path, -exitval => 0 );
+    pod2usage(-verbose => 2, -input => $absolute_path, -exitval => 0);
 
     return 1;
 }
@@ -61,8 +54,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -71,21 +62,53 @@ App::Pinto::Command::manual - show the full manual for a command
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
-=head1 SYNOPSIS
+=head1 CONTRIBUTORS
 
-  pinto manual COMMAND
+=over 4
 
-=head1 DESCRIPTION
+=item *
 
-This command shows the complete user manual for a pinto COMMAND.
+Cory G Watson <gphat@onemogin.com>
 
-=head1 COMMAND ARGUMENTS
+=item *
 
-The argument to this command is the name of the command for which you would
-like to see the manual.  You can also use the L<help|App::Pinto::Command::help> 
-command to get a brief summary of the command.
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
 
 =head1 AUTHOR
 
@@ -93,7 +116,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
