@@ -6,7 +6,6 @@ use strict;
 use warnings;
 
 use Class::Load;
-use Pinto::Util qw(is_remote_repo);
 
 #-----------------------------------------------------------------------------
 
@@ -14,15 +13,15 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     $self->usage_error('Arguments are not allowed')
-        if @{$args};
+      if @{ $args };
 
     return 1;
 }
@@ -30,18 +29,18 @@ sub validate_args {
 #------------------------------------------------------------------------------
 
 sub execute {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     my $global_opts = $self->app->global_options;
 
-    die "Must specify a repository root directory\n"
-        unless $global_opts->{root} ||= $ENV{PINTO_REPOSITORY_ROOT};
+    $global_opts->{root} ||= $ENV{PINTO_REPOSITORY_ROOT}
+        || die "Must specify a repository root directory\n";
 
-    die "Cannot migrate remote repositories\n"
-        if is_remote_repo( $global_opts->{root} );
+    $global_opts->{root} =~ m{^https?://}x
+        && die "Cannot migrate remote repositories\n";
 
-    my $class    = $self->load_migrator;
-    my $migrator = $class->new( %{$global_opts} );
+    my $class = $self->load_migrator;
+    my $migrator = $class->new( %{ $global_opts } );
     $migrator->migrate;
 
     return 0;
@@ -53,12 +52,12 @@ sub load_migrator {
 
     my $class = 'Pinto::Migrator';
 
-    my ( $ok, $error ) = Class::Load::try_load_class($class);
+    my ($ok, $error) = Class::Load::try_load_class($class);
     return $class if $ok;
 
-    my $msg = $error =~ m/Can't locate .* in \@INC/    ## no critic (ExtendedFormat)
-        ? "Must install Pinto to migrate repositories\n"
-        : $error;
+    my $msg = $error =~ m/Can't locate .* in \@INC/  ## no critic (ExtendedFormat)
+                     ? "Must install Pinto to migrate repositories\n"
+                     : $error;
     die $msg;
 }
 
@@ -69,8 +68,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -79,7 +76,7 @@ App::Pinto::Command::migrate - migrate repository to a new version
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -102,13 +99,59 @@ None.
 
 None.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
