@@ -11,24 +11,23 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
     return (
-        [ 'default'                   => 'Make the new stack the default stack' ],
-        [ 'description|d=s'           => 'Brief description of the stack' ],
-        [ 'target-perl-version|tpv=s' => 'Target Perl version for this stack' ],
+        [ 'default'               => 'Make the new stack the default stack' ],
+        [ 'description|d=s'       => 'Brief description of the stack'       ],
     );
 }
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     $self->usage_error('Must specify exactly one stack')
         if @{$args} != 1;
@@ -45,8 +44,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -55,7 +52,7 @@ App::Pinto::Command::new - create a new empty stack
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -89,14 +86,51 @@ Also mark the new stack as the default stack.
 
 Use TEXT for the description of the stack.
 
-=item --target-perl-version=VERSION
+=back
 
-=item --tpv=VERSION
+=head1 CONTRIBUTORS
 
-Sets the target perl version for the stack.  Pinto never pulls distributions
-for prerequisites that are satisfied by the core of the target perl version.
-VERSION must be a valid version number for an existing release of perl 5.
-Defaults to the global target Perl version of this repository.
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
 
 =back
 
@@ -106,7 +140,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
