@@ -11,18 +11,17 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-----------------------------------------------------------------------------
 
 sub opt_spec {
-    my ( $self, $app ) = @_;
+    my ($self, $app) = @_;
 
     return (
-        [ 'diff-style=s'          => 'Set style of diff reports' ],
-        [ 'dry-run'               => 'Do not commit any changes' ],
-        [ 'message|m=s'           => 'Message to describe the change' ],
-        [ 'stack|s=s'             => 'Pin targets to this stack' ],
+        [ 'dry-run'     => 'Do not commit any changes'           ],
+        [ 'message|m=s' => 'Message to describe the change'      ],
+        [ 'stack|s=s'   => 'Pin targets to this stack'           ],
         [ 'use-default-message|M' => 'Use the generated message' ],
     );
 }
@@ -43,8 +42,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -53,7 +50,7 @@ App::Pinto::Command::pin - force a package to stay in a stack
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -93,18 +90,6 @@ or ';') will be ignored.
 
 =over 4
 
-=item --diff-style=STYLE
-
-Controls the style of the diff reports.  STYLE must be either C<concise> or
-C<detailed>.  Concise reports show only one record for each distribution added
-or deleted.  Detailed reports show one record for every package added or
-deleted.
-
-The default style is C<concise>.  However, the default style can changed by
-setting the C<PINTO_DIFF_STYLE> environment variable to your preferred STYLE.
-This variable affects the default style for diff reports generated by all
-other commands too.
-
 =item --dry-run
 
 Go through all the motions, but do not actually commit any changes to
@@ -116,11 +101,12 @@ potentially impact the stack.
 =item -m TEXT
 
 Use TEXT as the revision history log message.  If you do not use the
-C<--message> option or the C<--use-default-message> option, then you will be
-prompted to enter the message via your text editor.  Use the C<PINTO_EDITOR>
-or C<EDITOR> or C<VISUAL> environment variables to control which editor is
-used.  A log message is not required whenever the C<--dry-run> option is set,
-or if the action did not yield any changes to the repository.
+C<--message> option or the C<--use-default-message> option, then you
+will be prompted to enter the message via your text editor.  Use the
+C<EDITOR> or C<VISUAL> environment variables to control which editor
+is used.  A log message is not required whenever the C<--dry-run>
+option is set, or if the action did not yield any changes to the
+repository.
 
 =item --stack=NAME
 
@@ -140,13 +126,59 @@ the C<--use-default-message> option will be silently ignored.
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
