@@ -13,22 +13,23 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub opt_spec {
 
-    return (
-        [ 'format=s'             => 'Format specification (See POD for details)' ],
-        [ 'properties|prop|P=s%' => 'name=value pairs of properties' ],
-    );
+  return (
+      [ 'format=s' => 'Format specification (See POD for details)' ],
+      [ 'properties|prop|P=s%' => 'name=value pairs of properties' ],
+  );
 }
 
 #------------------------------------------------------------------------------
 
+
 sub validate_args {
-    my ( $self, $opts, $args ) = @_;
+    my ($self, $opts, $args) = @_;
 
     $self->usage_error('Cannot specify multiple stacks')
         if @{$args} > 1;
@@ -49,8 +50,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -59,7 +58,7 @@ App::Pinto::Command::props - show or set stack properties
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -132,11 +131,53 @@ core and therefore does not need to be added to the stack.
 It must be a version string or number for an existing perl release, 
 and cannot be later than the latest version specified in your
 L<Module::CoreList>.  To target even newer perls, just install the 
-latest version of L<Module::CoreList>.  Remember that Pinto is often
-installed as a stand-alone application, so you will need to update
-Pinto's copy of L<Module::CoreList> - for example:
+latest version of L<Module::CoreList>.
 
- cpanm -L /opt/local/pinto/ Module::CoreList
+=back
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
 
 =back
 
@@ -146,7 +187,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
