@@ -11,30 +11,12 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
-
-#------------------------------------------------------------------------------
-
-# TODO: Add a --stack option, just like the "list" command.
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub command_names { return qw( statistics stats ) }
 
-#------------------------------------------------------------------------------
-
-sub validate_args {
-    my ( $self, $opts, $args ) = @_;
-
-    $self->usage_error('Multiple arguments are not allowed')
-        if @{$args} > 1;
-
-    $opts->{stack} = $args->[0]
-        if $args->[0];
-
-    return 1;
-}
-
 #------------------------------------------------------------------------------
 1;
 
@@ -42,8 +24,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -52,11 +32,11 @@ App::Pinto::Command::statistics - report statistics about the repository
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT statistics [STACK]
+  pinto --root=REPOSITORY_ROOT statistics
 
 =head1 DESCRIPTION
 
@@ -66,20 +46,65 @@ This command reports some statistics about the repository.
 
 =head1 COMMAND ARGUMENTS
 
-The argument is the name of the stack you wish to see the statistics for. If
-you do not specify a stack, then the default stack will be used.
+None.
 
 =head1 COMMAND OPTIONS
 
 None.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
