@@ -17,7 +17,7 @@ use Pinto::Util qw(current_username current_time_offset);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_06'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
@@ -146,6 +146,15 @@ has no_history => (
 );
 
 
+has allow_duplicates => (
+    is         => 'ro',
+    isa        => Bool,
+    key        => 'allow_duplicates',
+    default    => 0,
+    documentation => 'Allow this repository to contain duplicate distributions',
+);
+
+
 has sources  => (
     is        => 'ro',
     isa       => Str,
@@ -235,7 +244,7 @@ __END__
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
 
@@ -243,20 +252,66 @@ Pinto::Config - Internal configuration for a Pinto repository
 
 =head1 VERSION
 
-version 0.065_06
+version 0.079_01
 
 =head1 DESCRIPTION
 
 This is a private module for internal use only.  There is nothing for
 you to see here (yet).
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Imaginative Software Systems.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
