@@ -5,29 +5,18 @@ package Pinto::Globals;
 use strict;
 use warnings;
 
-use LWP::UserAgent;
-
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 ## no critic qw(PackageVars);
-our $current_utc_time    = undef;
-our $current_time_offset = undef;
-our $current_username    = undef;
-our $current_author_id   = undef;
-our $is_interactive      = undef;
-
-#------------------------------------------------------------------------------
-# TODO: Decide how to expose this
-
-our $UA = LWP::UserAgent->new(
-	agent      => 'Pinto/' . (__PACKAGE__->VERSION || '???'),
-   	env_proxy  => 1,
-   	keep_alive => 5,
-);
+our $current_utc_time     = undef;
+our $current_time_offset  = undef;
+our $current_username     = undef;
+our $current_author_id    = undef;
+our $is_interactive       = undef;
 
 #------------------------------------------------------------------------------
 1;
@@ -36,8 +25,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -46,7 +33,53 @@ Pinto::Globals - Global variables used across the Pinto utilities
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
 
 =head1 AUTHOR
 
@@ -54,7 +87,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
