@@ -4,10 +4,9 @@ package Pinto::Remote;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods ( autoclean => 1 );
+use MooseX::MarkAsMethods (autoclean => 1);
 use MooseX::Types::Moose qw(Maybe Str);
 
-use Try::Tiny;
 use LWP::UserAgent;
 
 use Pinto::Chrome::Term;
@@ -16,32 +15,51 @@ use Pinto::Constants qw(:server);
 use Pinto::Util qw(throw current_username);
 use Pinto::Types qw(Uri);
 
+
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
-with qw(Pinto::Role::Plated Pinto::Role::UserAgent);
+with qw(Pinto::Role::Plated);
 
 #------------------------------------------------------------------------------
 
 has root => (
-    is      => 'ro',
-    isa     => Uri,
-    default => $ENV{PINTO_REPOSITORY_ROOT},
-    coerce  => 1,
+    is       => 'ro',
+    isa      => Uri,
+    default  => $ENV{PINTO_REPOSITORY_ROOT},
+    coerce   => 1,
 );
 
+
 has username => (
     is      => 'ro',
     isa     => Str,
     default => current_username,
 );
 
+
 has password => (
-    is  => 'ro',
-    isa => Maybe [Str],
+    is      => 'ro',
+    isa     => Maybe[ Str ],
+);
+
+
+has ua    => (
+    is        => 'ro',
+    isa       => 'LWP::UserAgent',
+    default   => sub { LWP::UserAgent->new( agent => $_[0]->ua_name) },
+    lazy      => 1,
+);
+
+
+has ua_name => (
+    is      => 'ro',
+    isa     => Str,
+    default => sub { sprintf '%s/%s', ref $_[0], $_[0]->VERSION || '??' },
+    lazy    => 1,
 );
 
 #------------------------------------------------------------------------------
@@ -49,12 +67,20 @@ has password => (
 around BUILDARGS => sub {
     my $orig  = shift;
     my $class = shift;
+
     my $args = $class->$orig(@_);
 
+    # Normalize the root
+    $args->{root} = 'http://' . $args->{root}
+        if defined $args->{root} && $args->{root} !~ m{^ https?:// }mx;
+
+    $args->{root} = $args->{root} . ':' . $PINTO_SERVER_DEFAULT_PORT
+        if defined $args->{root} && $args->{root} !~ m{ :\d+ $}mx;
+
     # Grrr.  Gotta avoid passing undefs to Moose
-    my @chrome_attrs = qw(verbose quiet color);
-    my %chrome_args = map { $_ => delete $args->{$_} }
-        grep { exists $args->{$_} } @chrome_attrs;
+    my @chrome_attrs = qw(verbose quiet no_color);
+    my %chrome_args  = map  { $_ => delete $args->{$_} } 
+                       grep { exists $args->{$_}       } @chrome_attrs;
 
     $args->{chrome} ||= Pinto::Chrome::Term->new(%chrome_args);
 
@@ -65,42 +91,28 @@ around BUILDARGS => sub {
 
 
 sub run {
-    my ( $self, $action_name, @args ) = @_;
+    my ($self, $action_name, @args) = @_;
 
-    # Divert all warnings through our chrome
-    local $SIG{__WARN__} = sub { $self->warning($_) for @_ };
+    my $action_args = (@args == 1 and ref $args[0] eq 'HASH') ? $args[0] : {@args};
+    my $action_class = $self->load_class_for_action(name => $action_name);
 
-    my $action_args = ( @args == 1 and ref $args[0] eq 'HASH' ) ? $args[0] : {@args};
+    my $action = $action_class->new( name     => $action_name,
+                                     args     => $action_args,
+                                     root     => $self->root,
+                                     username => $self->username,
+                                     password => $self->password,
+                                     chrome   => $self->chrome,
+                                     ua       => $self->ua );
 
-    my $result = try {
-
-        my $action_class = $self->load_class_for_action( name => $action_name );
-
-        my $action = $action_class->new(
-            name     => $action_name,
-            args     => $action_args,
-            root     => $self->root,
-            username => $self->username,
-            password => $self->password,
-            chrome   => $self->chrome,
-        );
-
-        $action->execute;
-    }
-    catch {
-        $self->error($_);
-        Pinto::Result->new->failed( because => $_ );
-    };
-
-    return $result;
+    return $action->execute;
 }
 
 #------------------------------------------------------------------------------
 
 sub load_class_for_action {
-    my ( $self, %args ) = @_;
+    my ($self, %args) = @_;
 
-    my $action_name = $args{name}
+    my $action_name = $args{name} 
         or throw 'Must specify an action name';
 
     my $action_baseclass = __PACKAGE__ . '::Action';
@@ -126,8 +138,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -136,7 +146,7 @@ Pinto::Remote - Interact with a remote Pinto repository
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 SYNOPSIS
 
@@ -155,7 +165,7 @@ on the remote host.
 
 If you are using the L<pinto> application, it will automatically load
 either Pinto or Pinto::Remote depending on whether your repository
-root looks like a local directory path or a remote URI.
+root looks like a local directory path or a remote URL.
 
 =head1 METHODS
 
@@ -166,13 +176,59 @@ an object using the given C<$action_args>.  If the subclass
 C<Pinto::Remote::Action::$action_name> does not exist, then it falls
 back to the L<Pinto::Remote::Action> base class.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
