@@ -4,58 +4,68 @@ package Pinto::Remote::Action;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods ( autoclean => 1 );
+use MooseX::MarkAsMethods (autoclean => 1);
 use MooseX::Types::Moose qw(Str Maybe);
 
 use URI;
 use JSON;
 use HTTP::Request::Common;
 
-use Pinto::Result;
-use Pinto::Constants qw(:protocol);
-use Pinto::Util qw(current_time_offset);
+use Pinto::Remote::Result;
+use Pinto::Constants qw(:server);
 use Pinto::Types qw(Uri);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
-with qw(Pinto::Role::Plated Pinto::Role::UserAgent);
+with qw(Pinto::Role::Plated);
 
 #------------------------------------------------------------------------------
 
-has name => (
-    is       => 'ro',
-    isa      => Str,
-    required => 1,
+has name      => (
+    is        => 'ro',
+    isa       => Str,
+    required  => 1,
 );
 
+
 has root => (
     is       => 'ro',
     isa      => Uri,
     required => 1,
 );
 
-has args => (
-    is      => 'ro',
-    isa     => 'HashRef',
-    default => sub { {} },
+
+has args     => (
+    is       => 'ro',
+    isa      => 'HashRef',
+    default  => sub { {} },
 );
 
+
 has username => (
     is       => 'ro',
     isa      => Str,
     required => 1
 );
 
+
 has password => (
     is       => 'ro',
-    isa      => Maybe [Str],
+    isa      => Maybe[ Str ],
     required => 1,
 );
 
+
+has ua        => (
+    is        => 'ro',
+    isa       => 'LWP::UserAgent',
+    required  => 1,
+);
+
 #------------------------------------------------------------------------------
 
 
@@ -63,7 +73,7 @@ sub execute {
     my ($self) = @_;
 
     my $request = $self->_make_request;
-    my $result = $self->_send_request( req => $request );
+    my $result  = $self->_send_request(req => $request);
 
     return $result;
 }
@@ -71,21 +81,16 @@ sub execute {
 #------------------------------------------------------------------------------
 
 sub _make_request {
-    my ( $self, %args ) = @_;
+    my ($self, %args) = @_;
 
     my $action_name  = $args{name} || $self->name;
     my $request_body = $args{body} || $self->_make_request_body;
 
-    my $uri = URI->new( $self->root );
-    $uri->path_segments( '', 'action', lc $action_name );
+    my $url = URI->new( $self->root );
+    $url->path_segments('', 'action', lc $action_name);
 
-    my $request = POST(
-        $uri,
-        Accept        => $PINTO_PROTOCOL_ACCEPT,
-        Content       => $request_body,
-        Content_Type  => 'form-data',
-
-    );
+    my $request = POST( $url, Content_Type => 'form-data',
+                              Content      => $request_body );
 
     if ( defined $self->password ) {
         $request->authorization_basic( $self->username, $self->password );
@@ -94,6 +99,7 @@ sub _make_request {
     return $request;
 }
 
+
 #------------------------------------------------------------------------------
 
 sub _make_request_body {
@@ -102,17 +108,15 @@ sub _make_request_body {
     return [ $self->_chrome_args, $self->_pinto_args, $self->_action_args ];
 }
 
+
 #------------------------------------------------------------------------------
 
 sub _chrome_args {
     my ($self) = @_;
 
-    my $chrome_args = {
-        verbose  => $self->chrome->verbose,
-        color    => $self->chrome->color,
-        palette  => $self->chrome->palette,
-        quiet    => $self->chrome->quiet
-    };
+    my $chrome_args = { verbose  => $self->chrome->verbose,
+                        no_color => $self->chrome->no_color,
+                        quiet    => $self->chrome->quiet };
 
     return ( chrome => encode_json($chrome_args) );
 
@@ -123,10 +127,7 @@ sub _chrome_args {
 sub _pinto_args {
     my ($self) = @_;
 
-    my $pinto_args = {
-        username    => $self->username,
-        time_offset => current_time_offset,
-    };
+    my $pinto_args = { username  => $self->username };
 
     return ( pinto => encode_json($pinto_args) );
 }
@@ -144,50 +145,45 @@ sub _action_args {
 #------------------------------------------------------------------------------
 
 sub _send_request {
-    my ( $self, %args ) = @_;
+    my ($self, %args) = @_;
 
     my $request = $args{req} || $self->_make_request;
-    my $status = 0;
-    my $buffer = '';
+
+    my $status   = 0;
+    my $buffer   = '';
 
     # Currying in some extra args to the callback...
-    my $callback = sub { $self->_response_callback( \$status, \$buffer, @_ ) };
-    my $response = $self->request( $request, $callback );
+    my $callback = sub { $self->_response_callback(@_, \$status, \$buffer) };
+    my $response = $self->ua->request($request, $callback, 128);
 
-    if ( not $response->is_success ) {
-        $self->error( $response->content );
-        return Pinto::Result->new( was_successful => 0 );
+    if (not $response->is_success) {
+        $self->error($response->content);
+        return Pinto::Remote::Result->new(was_successful => 0);
     }
 
-    return Pinto::Result->new( was_successful => $status );
+    return Pinto::Remote::Result->new(was_successful => $status);
 }
 
 #------------------------------------------------------------------------------
 
-sub _response_callback {
-    my ( $self, $status, $buffer, $data ) = @_;
+sub _response_callback {                  ## no critic qw(ProhibitManyArgs)
+    my ($self, $data, $request, $proto, $status, $buffer) = @_;
 
-    $data = ${$buffer}.$data;
-    while($data =~ /\G([^\n]*)\n/gc) {
-        my $line = $1;
-        if ( $line eq $PINTO_PROTOCOL_STATUS_OK ) {
-            ${$status} = 1;
+    my $lines = '';
+    $lines = $1 if (${ $buffer } .= $data) =~ s{^ (.*)\n }{}sx;
+
+    for (split m{\n}x, $lines, -1) {
+
+        if ($_ eq $PINTO_SERVER_STATUS_OK) {
+            ${ $status } = 1;
         }
-        elsif ( $line eq $PINTO_PROTOCOL_PROGRESS_MESSAGE ) {
-            $self->chrome->show_progress;
-        }
-        elsif ( $line eq $PINTO_PROTOCOL_NULL_MESSAGE ) {
-            # Do nothing, discard message
-        }
-        elsif ( $line =~ m{^ \Q$PINTO_PROTOCOL_DIAG_PREFIX\E (.*)}x ) {
-            $self->chrome->diag($1);
+        elsif (m{^ \Q$PINTO_SERVER_DIAG_PREFIX\E (.*)}x) {
+            print {$self->chrome->stderr} "$1\n";
         }
         else {
-            $self->chrome->show($line);
+            print {$self->chrome->stdout} "$_\n";
         }
     }
-    #Save leftovers, use them in next packet
-    (${$buffer}) = ($data =~ /\G(.*)$/g);
 
     return 1;
 }
@@ -203,8 +199,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -213,14 +207,61 @@ Pinto::Remote::Action - Base class for remote Actions
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 METHODS
 
 =head2 execute
 
 Runs this Action on the remote server by serializing itself and
-sending a POST request to the server.  Returns a L<Pinto::Result>.
+sending a POST request to the server.  Returns a
+L<Pinto::Remote::Result>.
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
 
 =head1 AUTHOR
 
@@ -228,7 +269,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
