@@ -24,7 +24,7 @@ use version;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.065_06'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -222,7 +222,6 @@ sub get_distribution {
         throw 'Invalid arguments';
     }
 
-
     # Retrieve a distribution by its path (e.g. AUTHOR/Dist-1.0.tar.gz)
     elsif (my $path = $args{path}) {
         my ($author, $archive) = Pinto::Util::parse_dist_path($path);
@@ -232,22 +231,6 @@ sub get_distribution {
                                 ->find_by_author_archive($author, $archive);
     }
 
-
-    # Retrieve a distribution by its SHA-256 digest
-    elsif (my $sha256 = $args{sha256}) {
-         return $self->db->schema->distribution_rs
-                                 ->with_packages
-                                 ->find_by_sha256($sha256);
-    }
-
-
-    # Retrieve a distribution by its MD5 digest
-    elsif (my $md5 = $args{md5}) {
-         return $self->db->schema->distribution_rs
-                                 ->with_packages
-                                 ->find_by_md5($md5);
-    }
-
     # Retrieve a distribution by author and archive
     elsif (my $author = $args{author}) {
         my $archive = $args{archive} or throw "Must specify archive with author";
@@ -314,6 +297,10 @@ sub add_distribution {
     my @requires = $extractor->requires;
     $dist_struct->{prerequisites} = \@requires;
 
+    # Add metadata...
+    my $metadata = $extractor->metadata;
+    $dist_struct->{metadata} = $metadata;
+
     my $p = scalar @provides;
     my $r = scalar @requires;
     debug "Distribution $archive provides $p and requires $r packages";
@@ -663,12 +650,13 @@ sub assert_archive_not_duplicate {
         throw "A distribution already exists as $same_path";
     }
 
-    my $sha256 = Pinto::Util::sha256($archive);
-    if (my $same_sha = $self->get_distribution(sha256 => $sha256)) {
-        throw "Archive $archive is identical to $same_sha";
+    unless ( $self->config->allow_duplicates) {
+        my $sha256 = Pinto::Util::sha256($archive);
+        my $dupe = $self->db->schema->search_distribution({sha256 => $sha256})->first;
+        throw "Archive $archive is identical to $dupe" if $dupe;
     }
 
-    return;
+    return $self;
 }
 
 #-------------------------------------------------------------------------------
@@ -691,7 +679,7 @@ sub assert_version_ok {
         throw $msg;
     }
 
-    return;
+    return $self;
 }
 
 #-------------------------------------------------------------------------------
@@ -706,7 +694,7 @@ sub assert_sanity_ok {
         throw "Directory $root_dir does not look like a Pinto repository";
     }
 
-    return;
+    return $self;
 }
 
 #-------------------------------------------------------------------------------
@@ -732,7 +720,7 @@ __END__
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
 
@@ -740,7 +728,7 @@ Pinto::Repository - Coordinates the database, files, and indexes
 
 =head1 VERSION
 
-version 0.065_06
+version 0.079_01
 
 =head1 ATTRIBUTES
 
@@ -849,12 +837,6 @@ returns the L<Pinto::Schema::Result::Distribution> from this repository that is
 identified by the author ID and archive file name in the path.  Returns nothing
 if no such distribution is found.
 
-=head2 get_distribution( sha256 => $sha256 )
-
-Given an SHA-256 digest as a string of hexadecimal characters, returns the
-L<Pinto::Schema::Result::Distribution> from this repository with the same 
-digest.  Returns nothing if no such distribution is found.
-
 =head2 get_distribution( author => $author, archive => $archive )
 
 Given an author id and a distribution archive file basename, returns the 
@@ -903,13 +885,59 @@ Deletes all distribution archives that are on the filesystem but not
 in the database.  This can happen when an Action fails or is aborted
 prematurely.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Imaginative Software Systems.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
