@@ -15,7 +15,7 @@ use Pinto::Util qw(is_interactive throw is_blank is_not_blank);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_06'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -68,7 +68,9 @@ requires qw( execute repo );
 around BUILD => sub {
     my ($orig, $self) = @_;
 
-    $self->_set_stack( $self->repo->get_stack($self->stack) );
+    my $stack = $self->repo->get_stack($self->stack);
+    $stack->assert_not_locked;
+    $self->_set_stack($stack);
 
     return $self->$orig;
 };
@@ -158,7 +160,7 @@ __END__
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
 
@@ -166,7 +168,53 @@ Pinto::Role::Committable - Role for actions that commit changes to the repositor
 
 =head1 VERSION
 
-version 0.065_06
+version 0.079_01
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
 
 =head1 AUTHOR
 
@@ -174,7 +222,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Imaginative Software Systems.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
