@@ -3,47 +3,47 @@
 package Pinto::Role::PauseConfig;
 
 use Moose::Role;
-use MooseX::Types::Moose qw(HashRef);
 
-use Pinto::Globals;
+use MooseX::Types::Moose qw(HashRef);
 use Pinto::Types qw(File);
-use Pinto::Util qw(current_author_id);
 
 use Path::Class;
 use File::HomeDir;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 
 has pauserc => (
-    is      => 'ro',
-    isa     => File,
-    lazy    => 1,
-    coerce  => 1,
-    builder => '_build_pauserc',
+    is         => 'ro',
+    isa        => File,
+    lazy       => 1,
+    coerce     => 1,
+    builder    => '_build_pauserc',
 );
 
+
 #------------------------------------------------------------------------------
 
 
 has pausecfg => (
-    is       => 'ro',
-    isa      => HashRef,
-    lazy     => 1,
-    init_arg => undef,
-    builder  => '_build_pausecfg',
+    is        => 'ro',
+    isa       => HashRef,
+    lazy      => 1,
+    init_arg  => undef,
+    builder   => '_build_pausecfg',
 );
 
+
 #------------------------------------------------------------------------------
 
 sub _build_pauserc {
     my ($self) = @_;
 
-    return file( File::HomeDir->my_home, '.pause' );
+    return file(File::HomeDir->my_home, '.pause');
 }
 
 #------------------------------------------------------------------------------
@@ -52,7 +52,6 @@ sub _build_pausecfg {
     my ($self) = @_;
 
     my $cfg = {};
-    return $cfg if $Pinto::Globals::current_author_id;
     return $cfg if not -e $self->pauserc();
     my $fh = $self->pauserc->openr();
 
@@ -61,7 +60,7 @@ sub _build_pausecfg {
 
     while (<$fh>) {
         next if /^ \s* (?: [#].*)? $/x;
-        my ( $k, $v ) = /^ \s* (\w+) \s+ (.+?) \s* $/x;
+        my ($k, $v) = /^ \s* (\w+) \s+ (.+?) \s* $/x;
         next unless $k;
         $cfg->{$k} = $v;
     }
@@ -76,8 +75,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer pauserc pausecfg
 
 =head1 NAME
@@ -86,7 +83,7 @@ Pinto::Role::PauseConfig - Something that has a pause config attribute
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 ATTRIBUTES
 
@@ -100,13 +97,59 @@ The path to your PAUSE config file.  By default, this is F<~/.pause>.
 
 Returns a hashref representing the data of the PAUSE config file.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
