@@ -20,16 +20,16 @@ use Pinto::Repository;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
 
-has root => (
-    is       => 'ro',
-    isa      => Dir,
-    required => 1,
-    coerce   => 1,
+has root  => (
+   is       => 'ro',
+   isa      => Dir,
+   required => 1,
+   coerce   => 1,
 );
 
 
@@ -49,18 +49,20 @@ has router => (
 );
 
 
+
 class_has default_port => (
-    is      => 'ro',
-    isa     => Int,
-    default => $PINTO_SERVER_DEFAULT_PORT,
+    is       => 'ro',
+    isa      => Int,
+    default  => $PINTO_SERVER_DEFAULT_PORT,
 );
 
+
 #-------------------------------------------------------------------------------
 
 sub BUILD {
     my ($self) = @_;
 
-    my $repo = Pinto::Repository->new( root => $self->root );
+    my $repo = Pinto::Repository->new(root => $self->root);
     $repo->assert_sanity_ok;
 
     return $self;
@@ -74,7 +76,7 @@ sub to_app {
 
     my $app = sub { $self->call(@_) };
 
-    if ( my %auth_options = $self->auth_options ) {
+    if (my %auth_options = $self->auth_options) {
 
         my $backend = delete $auth_options{backend}
             or carp 'No auth backend provided!';
@@ -83,7 +85,8 @@ sub to_app {
         print "Authenticating using $class\n" if is_interactive;
         Class::Load::load_class($class);
 
-        $app = Plack::Middleware::Auth::Basic->wrap( $app, authenticator => $class->new(%auth_options) );
+        $app = Plack::Middleware::Auth::Basic->wrap($app,
+            authenticator => $class->new(%auth_options) );
     }
 
     return $app;
@@ -93,12 +96,12 @@ sub to_app {
 
 
 sub call {
-    my ( $self, $env ) = @_;
+    my ($self, $env) = @_;
 
-    my $response = $self->router->route( $env, $self->root );
+    my $response = $self->router->route($env, $self->root);
 
     $response = $response->finalize
-        if blessed($response) && $response->can('finalize');
+      if blessed($response) && $response->can('finalize');
 
     return $response;
 }
@@ -110,8 +113,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -120,7 +121,7 @@ Pinto::Server - Web interface to a Pinto repository
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 ATTRIBUTES
 
@@ -162,13 +163,59 @@ There is nothing to see here.
 
 Look at L<pintod> if you want to start the server.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
