@@ -11,7 +11,7 @@ use HTTP::Date ();
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -23,28 +23,32 @@ sub respond {
     my ($self) = @_;
 
     # e.g. /stack_name/modules/02packages.details.txt.gz
-    my ( undef, @path_parts ) = split '/', $self->request->path_info;
+    my (undef, @path_parts) = split '/', $self->request->path_info;
+
     my $file = $self->root->file(@path_parts);
 
-    return not_found($file) if not -f $file;
-    return not_found($file) if index($file, '/../') > 0;
-
     my @stat = stat($file);
+    unless (-f _) {
+        my $body = "File $file not found";
+        my $headers = ['Content-Type' => 'text/plain', 'Content-Length' => length($body)];
+        return [404, $headers, [$body]];
+    }
+
     my $modified_since = HTTP::Date::str2time( $self->request->env->{HTTP_IF_MODIFIED_SINCE} );
-    return [ 304, [], [] ] if $modified_since && $stat[9] <= $modified_since;
+    return [304, [], []] if $modified_since && $stat[9] <= $modified_since;
 
     my $response = Plack::Response->new;
     $response->content_type( Plack::MIME->mime_type($file) );
     $response->content_length( $stat[7] );
-    $response->header( 'Last-Modified' => HTTP::Date::time2str( $stat[9] ) );
+    $response->header( 'Last-Modified' => HTTP::Date::time2str($stat[9]) );
 
     $response->header( 'Cache-Control' => 'no-cache' ) if $self->should_not_cache($file);
 
     $response->body( $file->openr ) unless $self->request->method eq "HEAD";
-    $response->status(200);
+    $response->status( 200 );
 
     return $response;
-}
+ }
 
 #-------------------------------------------------------------------------------
 
@@ -52,7 +56,7 @@ sub respond {
 #-------------------------------------------------------------------------------
 
 sub should_not_cache {
-    my ( $self, $file ) = @_;
+    my ($self, $file) = @_;
 
     # force caches to always revalidate the indices, i.e.
     # 01mailrc.txt.gz, 02packages.details.txt.gz, 03modlist.data.gz
@@ -67,15 +71,6 @@ sub should_not_cache {
 
 #-------------------------------------------------------------------------------
 
-sub not_found {
-    my $file = shift;
-    my $body = "File $file not found";
-    my $headers = [ 'Content-Type' => 'text/plain', 'Content-Length' => length($body) ];
-    return [ 404, $headers, [$body] ];
-}
-
-#-------------------------------------------------------------------------------
-
 __PACKAGE__->meta->make_immutable;
 
 #-------------------------------------------------------------------------------
@@ -86,8 +81,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer
 
 =head1 NAME
@@ -96,7 +89,7 @@ Pinto::Server::Responder::File - Responder for static files
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 METHODS
 
@@ -106,13 +99,59 @@ Returns true if the file should not be cached, and therefore the Cache-Control
 header should be set to 'no-cache' in the response.  Currently, only the index
 files should not be cached.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
