@@ -10,7 +10,7 @@ use Router::Simple;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.079_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -23,41 +23,43 @@ has route_handler => (
 #-------------------------------------------------------------------------------
 
 sub BUILD {
-    my ($self) = @_;
+  my ($self) = @_;
 
-    my $r = $self->route_handler;
+  my $r = $self->route_handler;
 
-    $r->connect( '/action/{action}', { responder => 'Action' }, { method => 'POST' } );
+  $r->connect( '/action/{action}',
+               {responder => 'Action'}, {method => 'POST'} );
 
-    $r->connect( '/*', { responder => 'File' }, { method => [ 'GET', 'HEAD' ] } );
+  $r->connect( '/*',
+               {responder => 'File'  }, {method => ['GET', 'HEAD'] } );
 
-    return $self;
+  return $self;
 }
 
 #-------------------------------------------------------------------------------
 
 
 sub route {
-    my ( $self, $env, $root ) = @_;
+    my ($self, $env, $root) = @_;
 
     my $p = $self->route_handler->match($env)
-        or return [ 404, [], ['Not Found'] ];
+      or return [404, [], ['Not Found']];
 
     my $responder_class = 'Pinto::Server::Responder::' . $p->{responder};
     Class::Load::load_class($responder_class);
 
-    my $request = Plack::Request->new($env);
-    my $responder = $responder_class->new( request => $request, root => $root );
+    my $request   = Plack::Request->new($env);
+    my $responder = $responder_class->new(request => $request, root => $root);
 
     # HACK: Plack-1.02 calls URI::Escape::uri_escape() with arguments
     # that inadvertently cause $_ to be compiled into a regex.  This
     # will emit warning if $_ is undef, or may blow up if it contains
-    # certain stuff.  To avoid this, just make sure $_ is empty for
+    # certains stuff.  To avoid this, just make sure $_ is empty for
     # now.  A patch has been sent to Miyagawa.
     local $_ = '';
 
     return $responder->respond;
-}
+};
 
 #-------------------------------------------------------------------------------
 
@@ -71,8 +73,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Jeffrey Ryan Thalhammer responder
 
 =head1 NAME
@@ -81,7 +81,7 @@ Pinto::Server::Router - Routes server requests
 
 =head1 VERSION
 
-version 0.11_01
+version 0.079_01
 
 =head1 METHODS
 
@@ -93,13 +93,59 @@ response.
 
 =for Pod::Coverage BUILD
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeff <jeff@callahan.local>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Jeffrey Thalhammer <jeff@imaginative-software.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=item *
+
+Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2013 by Jeffrey Ryan Thalhammer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
